Function iota_wallet::secret::ledger_nano::needs_blind_signing
[−]pub fn needs_blind_signing(
prepared_transaction: &PreparedTransactionData,
buffer_size: usize
) -> boolExpand description
needs_blind_signing the Ledger Nano S(+)/X app can present the user a detailed view of the transaction before it is signed but only with BasicOutputs, without extra-features and if the Essence is not too large. If criteria are not met, blind signing is needed. This method finds out if we have to switch to blind signing mode.